/*************************************************************************/
/*************************************************************************/
/*                                                                       */
/*                   OSKit Module 2: Display routines                    */
/*                                                                       */
/*************************************************************************/
/*************************************************************************/

#include <dos.h>
#include <bios.h>
#include "..\os.h"

PRIVATE int video = 0xb800;  /* default */

void display_init()
{
/*
 - determines the type of display unit (colour or monochrome) that this 
   machine uses.
 - the type is determined by the BIOS call 0x11
 - the AX register returns a mask indicating the type
*/

video = ((biosequip() & 0x30) == 0x30) ? 0xB000 : 0xB800;

}

void display(int line, int col, char ch)
{
/*
 - simplified display routine
 - writes a character to the specified line-column
 - attributes are not supported
 - maximum size is 25 x 80 x 2 or 4000 locations (or 2000 char:attr pairs)
*/
char *vptr;     /* Pointer to video area */

vptr = MK_FP(video, (line * 160 + col * 2) % 4000);

*vptr = ch;
}


int message(int row, int col, char *str)
{
/*
 - displays the contents of a string, starting at screen location row, col
 - no check is made on the string length, nor are row and col inspected
 - returns the next free column space
*/

while (*str)
	display(row, col++, *str++);

return col;

}


void erase_screen()
{
/*
 - clears the screen with blanks
*/
int row, col;

for(row = 0; row<24; row++)
	for(col = 0; col<80; col++)
		display(row, col, ' ');

}

void scroll_region(int uly, int ysz, int ulx, int xsz)
{
/*
 - copy uly+1..ysz-1,ulx+0..xsz-1 to uly+0..ysz-2,ulx+0..xsz-1
 - bottom line is blanked
*/
char *oldpos;
char *newpos;
int colx2;
int line;
int col;

for(line=uly; line <= (uly + ysz - 2); line++)
	for(col=ulx; col < (ulx + xsz); col++)
	{
		colx2 = col * 2;
		newpos = MK_FP(video, (line * 160 + colx2));
		oldpos = MK_FP(video, ((line + 1) * 160 + colx2));
		*newpos = *oldpos;
	}

line = uly + ysz - 1;
for(col=ulx; col < (ulx + xsz); col++)
	display(line, col, ' ');


}
